@@ -16,22 +16,18 @@ function createCalendarLink(id) {
     return Jifty.Calendar.registerDateWidget( id );
 }
 
-function buttonToLink(input) {
-    var e = $(input);
-    if (e) {
-        var link = document.createElement("a");
-        link.setAttribute("href","#");
-        link.setAttribute("onclick",e.getAttribute("onclick"));
-        link.setAttribute("name",e.getAttribute("name"));
-        link.className = e.className;
-        link['virtualform'] = Form.Element.getForm(e);
-        link.appendChild(document.createTextNode(e.getAttribute("value")));
+function buttonToLink(e) {
+    var link = document.createElement("a");
+    link.setAttribute("href","#");
+    link.setAttribute("onclick",e.getAttribute("onclick"));
+    link.setAttribute("name",e.getAttribute("name"));
+    link.className = e.className;
+    link['virtualform'] = Form.Element.getForm(e);
+    link.appendChild(document.createTextNode(e.getAttribute("value")));
 
-        e.parentNode.insertBefore(link, e.nextSibling);
-        e.parentNode.removeChild(e);
-        return true;
-    }
-    return false;
+    e.parentNode.insertBefore(link, e.nextSibling);
+    e.parentNode.removeChild(e);
+    return true;
 }
 
 // onload handlers
